==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/pt_BR.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Carregando pré-visualização...",
    "Saved" : "Salva",
    "Admin" : "Administrador",
    "a safe home for all your data" : "um lugar seguro para seus dados",
    "The given name is too long" : "O nome é muito longo",
    "The given web address is too long" : "O endereço web fornecido é muito longo",
    "The given slogan is too long" : "O slogan dado é muito longo",
    "The given color is invalid" : "A cor fornecida é inválida",
    "No file uploaded" : "Nenhum arquivo enviado",
    "Unsupported image type" : "Tipo de imagem não suportado",
    "You are already using a custom theme" : "Você já está usando um tema personalizado",
    "Theming" : "Personalização",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Criar e alterar temas torna possível personalizar facilmente o Nextcloud e clientes suportados. Isso será visível a todos os usuários.",
    "Name" : "Nome",
    "reset to default" : "restaurar ao padrão",
    "Web address" : "Endereço web",
    "Web address https://…" : "Endereço web https://...",
    "Slogan" : "Slogan",
    "Color" : "Cor",
    "Logo" : "Logotipo",
    "Upload new logo" : "Enviar novo logotipo",
    "Login image" : "Imagem de login",
    "Upload new login background" : "Enviar nova imagem de fundo para o login",
    "Remove background image" : "Excluir a imagem de fundo",
    "Log in image" : "Imagem de fundo do login"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-12.0.3-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/pt_BR.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Carregando pré-visualização...",
    "Saved" : "Salva",
    "Admin" : "Administrador",
    "a safe home for all your data" : "um lugar seguro para seus dados",
    "The given name is too long" : "O nome é muito longo",
    "The given web address is too long" : "O endereço web fornecido é muito longo",
    "The given slogan is too long" : "O slogan dado é muito longo",
    "The given color is invalid" : "A cor fornecida é inválida",
    "No file uploaded" : "Nenhum arquivo enviado",
    "Unsupported image type" : "Tipo de imagem não suportado",
    "You are already using a custom theme" : "Você já está usando um tema personalizado",
    "Theming" : "Personalização",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Criar e alterar temas torna possível personalizar facilmente o Nextcloud e clientes suportados. Isso será visível para todos os usuários.",
    "Name" : "Nome",
    "Reset to default" : "Redefinir para o padrão",
    "Web address" : "Endereço web",
    "Web address https://…" : "Endereço web https://...",
    "Slogan" : "Slogan",
    "Color" : "Cor",
    "Logo" : "Logotipo",
    "Upload new logo" : "Enviar novo logotipo",
    "Login image" : "Imagem de login",
    "Upload new login background" : "Enviar nova imagem de fundo para o login",
    "Remove background image" : "Excluir a imagem de fundo",
    "reset to default" : "restaurar ao padrão",
    "Log in image" : "Imagem do login"
},
"nplurals=2; plural=(n > 1);");
